@@ -54,7 +54,9 @@ class ReleaseValueOption(click.Option):
 
     def get_help_record(self: T, ctx: click.Context) -> typing.Tuple[str, str]:
         """Customize help text."""
-        help = super(ReleaseValueOption, self).get_help_record(ctx)
+        help = typing.cast(
+            typing.Tuple[str, str], super(ReleaseValueOption, self).get_help_record(ctx)
+        )
         return (help[0].replace("_set ", " "),) + help[1:]
 
 
@@ -124,11 +126,11 @@ def package(ctx: click.Context, release_id: typing.Optional[str]) -> None:
             message = str(e)
             log.error(message)
             report_console_error(message)
-            sys.exit(ExitState.PACKAGING_FAILED)
+            sys.exit(ExitState.PACKAGING_FAILED.value)
         finally:
             version_file_path.unlink(missing_ok=True)
     except Exception:
         message = "Unexpected error. Check log for details."
         log.exception(message)
         report_console_error(message)
-        sys.exit(ExitState.UNKNOWN_ERROR)
+        sys.exit(ExitState.UNKNOWN_ERROR.value)
