@@ -7,7 +7,10 @@
 #  If not, see <https://opensource.org/licenses/MIT>.
 #
 
-from build_harness.commands._release_id import validate_release_id
+import pytest
+from parver import ParseError
+
+from build_harness.commands._release_id import InvalidReleaseId, validate_release_id
 
 
 def test_public_release():
@@ -45,3 +48,25 @@ def test_local_dryrun():
     assert result.post == 11
     assert result.local == "dryrun"
     assert str(result) == expected_release
+
+
+def test_dev_release():
+    expected_release = "3.1.4.post11.dev456"
+    result = validate_release_id(expected_release)
+
+    assert result.public == "3.1.4.post11.dev456"
+    assert result.post == 11
+    assert result.dev == 456
+    assert str(result) == expected_release
+
+
+def test_failed_parse_raises(mocker):
+    expected_release = "bad_tag"
+
+    mocker.patch(
+        "build_harness.commands._release_id.parver.Version.parse",
+        side_effect=ParseError("some error"),
+    )
+
+    with pytest.raises(InvalidReleaseId, match=r"^Tags must be PEP-440 compliant"):
+        validate_release_id(expected_release)
