@@ -21,7 +21,7 @@ from build_harness._project import (
     acquire_source_dir,
 )
 
-MOCK_PROJECT_DIR = pathlib.Path("some/path")
+MOCK_PROJECT_DIR = pathlib.Path("some/test_project/path")
 
 
 class TestAcquirePyprojecttomlData:
